function [r,t,f] = cart2sph(x,y,z)
% CART2SPH converts cartesian coordinates to spherical
%   [R,T,F] = CART2SPH(X,Y,Z) Converts the cartesian <X,Y,Z> coordinates to
%   spherical <R,T,F> coordinates, where R is the radial distance, T is the
%   latitude/elevation angle (in radians), and F is the longitude/azimuth angle
%   (also in radians). X,Y,Z can be any size, but must be the same size or
%   scalar.
%------------------------------------------------------------------------------%
%
%   Version 1.0  Date: 2016/02/05
%
%   Copyright 2016 Aaron Hendry <aaron@hendry.co.nz>
%   Otago University Space Physics Department, Dunedin, New Zealand
%       <http://www.physics.otago.ac.nz/space>
%   Released under the Simplified BSD License:
%       <http://opensource.org/licenses/BSD-2-Clause>
%
%------------------------------------------------------------------------------%

sq = x.^2+y.^2;
r = sqrt(sq+z.^2);
sq = sqrt(sq);
f = atan2(y,x);
t = atan2(sq,z);