function [xg,yg,zg] = mag2geo(xm,ym,zm,time)
% GEO2MAG converts from cartesian geomagnetic to geocentric coordinates
%	[XM,YM,ZM] = GEO2MAG(XG,YG,ZG,TIME) Converts from cartesian geomagnetic
%	coordinates <XM,YM,ZM> to cartesian geocentric coordinates <XG,YG,ZG>,
%	using the Earth's dipole vector, calculated using the IGRF model. The dipole
%	vector is calculated using the TIME variable, which must be a MATLAB DATENUM
%	variable. XM,YM,ZM can be any size, but must all be the same size, or
%	scalar.
%
%------------------------------------------------------------------------------%
%
%   Version 1.0  Date: 2016/02/05
%
%   Copyright 2016 Aaron Hendry <aaron@hendry.co.nz>
%   Otago University Space Physics Department, Dunedin, New Zealand
%       <http://www.physics.otago.ac.nz/space>
%   Released under the Simplified BSD License:
%       <http://opensource.org/licenses/BSD-2-Clause>
%
%------------------------------------------------------------------------------%

[clat,slat,clon,slon] = dipole(time);

xz = xm*clat+zm*slat;
xg = xz*clon - ym*slon;
yg = xz*slon + ym*clon;
zg = zm*clat - xm*slat;